
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Inputs:
%   -rh: relative humidity
%   -dist: Tx-Rx distance
%   -file_name:the .picotd file name that is obtained using Picometrix system
%Outputs:
%   -time domain plot
%   -filtered time domain plot where the oscilations after the main one are
%   omitted
%   -frequency domain plot
%   -absorption coefficient based on the rh level   
%   -transfer function of the channel (H)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function mainFunction(rh, dist, file_name)
close all;
clc;

Ts = 78.125e-15; %sample time
c = 2.997925e8;  %light velocity m/s



%Read the pico.td file
[t, x] = readPicotd(file_name);
drawDiagram(t, x, 'Time', 'Amplitude', 'Time domain plot')

%Filter time domain plot to get rid of excess oscillations 
x_filtered = filterTimeDomain(x);
drawDiagram(t, x_filtered, 'Time(ps)', 'Amplitude', 'Filtered time domain plot')


%fft points
N = length(x);
Freq  = ([0:1:N-1]/N)* (1/Ts); %find the frequency axis

X = fft(x_filtered, N);%frequency doamin of the signal
drawDiagram(Freq, abs(X), 'Frequency(Hz)', 'Amplitude', 'Frequency domain')

[total_absorption] = absorption(Freq, rh);

Ind = find(Freq<=2e12,1,'last');%find the frequency index of 2 THz
str = sprintf('Absorption coefficient with relative humidity of %d%%',rh);
drawDiagram(Freq(1:Ind), 10*log10(total_absorption(1:Ind)), 'Freq(Hz)', 'Total Absorption coefficient (dB/cm)', str);


H = zeros(1, length(Freq)); %H is the transfer function of the channel
coef = zeros(1, length(Freq));
taw = dist* 0.01/c;%time delay for the signal to travel between Tx and Rx
for Freq_index = 1: length(Freq)/2+1
    coef(Freq_index) = exp(-1*(total_absorption(Freq_index)*dist));
    H(Freq_index) = coef(Freq_index)*exp(-1i*2*pi*Freq(Freq_index)*taw);
end
H(end:-1:end-N/2+1) = H(1:1:N/2); %H should be symmetric for negative and positive frequnecies

end

